# Hexafonter

A command-line tool that will convert a PNG file with a fixed-width pixel font
for small LCD displays, to a C file with a sideways preview and a character
code legend.

See [GitHub](https://github.com/encukou/hexafonter) for more info.
